@@ -8,6 +8,9 @@
 /* Bug report URL. */
 #define BUG_REPORT_URL "http://llvm.org/bugs/"
 
+/* Default C++ stdlib to use. */
+#define CLANG_DEFAULT_CXX_STDLIB ""
+
 /* Default OpenMP runtime used by -fopenmp. */
 #define CLANG_DEFAULT_OPENMP_RUNTIME "libomp"
 
@@ -30,9 +33,15 @@
 #define CLANG_HAVE_LIBXML 1
 
 /* The LLVM product name and version */
-#define BACKEND_PACKAGE_STRING "LLVM 3.8.1"
+#define BACKEND_PACKAGE_STRING "LLVM 3.9.0"
 
 /* Linker version detected at compile time. */
 /* #undef HOST_LINK_VERSION */
 
+/* pass --build-id to ld */
+/* #undef ENABLE_LINKER_BUILD_ID */
+
+/* enable x86 relax relocations by default */
+#define ENABLE_X86_RELAX_RELOCATIONS 0
+
 #endif
